TextCellValue class

Represents a text value in a cell, supporting rich text through spans.

Inheritance

Constructors

TextCellValue(String text)
Creates a new TextCellValue from a simple string.
TextCellValue.span(TextSpan value)
Creates a new TextCellValue from a TextSpan for rich text support.

Properties

defaultFormat NumFormat
The default format for this cell value type.
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value TextSpan
The text content as a TextSpan.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
write(NumFormat? format) String
Writes the value as a string using the given format. If format is null or incompatible, defaultFormat should be used.
override

Operators

operator ==(Object other) bool
The equality operator.
override