excel_community library
A community-maintained fork of the excel library for reading, creating, editing and updating excel sheets.
Supports XLSX format with client and server-side compatibility, including chart support.
Classes
- AccentColors
- Accent colors for Excel.
- AreaChart
- Represents an Excel Area Chart.
- AreaChartBuilder
- Builder for Area chart styles with transparency and grouping.
- BarChart
- Represents an Excel Bar Chart (Horizontal bars). Note: For vertical bars, use ColumnChart with isVertical=true.
- BaseColors
- BlueColors
- BoolCellValue
- Represents a boolean value in a cell.
- Border
- BubbleChart
- Represents an Excel Bubble Chart (3D data comparison: X, Y, and Bubble Size).
- BubbleChartBuilder
- Builder for Bubble chart styles.
- CellIndex
- CellStyle
- Styling class for cells
- CellValue
- Base class for all cell value types in an Excel sheet.
- Chart
- Base class for all Excel charts.
- ChartAnchor
- Defines the position and size of a chart on the worksheet.
- ChartColorConfig
- Configuration for chart colors and palettes.
- ChartDataLabels
- Configuration for data labels displayed on chart series.
- ChartSeries
- Represents a single data series in a chart.
- ChartSeriesStyle
- Per-series visual styling for charts.
- ChartStyleBuilder
- Base interface for chart-specific styling builders.
- ChartStyleBuilderFactory
- Factory to get the appropriate style builder for a chart type
- ChartXmlWriter
- Internal utility to generate XML for Charts and Drawings.
- ColumnBarChartBuilder
- Builder for Column and Bar chart styles
- ColumnChart
- Represents an Excel Column/Bar Chart.
- ConditionalFormattingGroup
-
Represents a collection of rules associated with a specific cell range (
sqref). - ConditionalFormattingRule
-
Represents a single rule (
<cfRule>) inside a conditional formatting group. - CustomDateTimeNumFormat
- CustomNumericNumFormat
- CustomNumFormat
- CustomTimeNumFormat
- Data
- DateCellValue
- Represents a date value in a cell.
- DateTimeCellValue
- Excel does not know if this is UTC or not. Use methods asDateTimeLocal or asDateTimeUtc to get the DateTime object you prefer.
- DateTimeNumFormat
- DifferentialStyle
-
Differential style representation used in OpenXML
<dxf>elements for conditional formatting styling. - DoubleCellValue
- Represents a double (floating-point) value in a cell.
- DoughnutChart
- Represents an Excel Doughnut Chart (Pie chart with a hole).
- Excel
- Main entry point for interacting with Excel files in XLSX format.
- ExcelColor
- Copying from Flutter Material Color
- ExcelImage
- Represents an image to be embedded in an Excel worksheet.
-
FastList<
K> - FormulaCellValue
- Represents a formula in a cell.
- GreenColors
- ImageAnchor
- Defines the position and size of an image embedded in a worksheet.
- IntCellValue
- Represents an integer value in a cell.
- LineChart
- Represents an Excel Line Chart.
- LineChartBuilder
- Builder for Line chart styles.
- NumericNumFormat
- NumFormat
- NumFormatMaintainer
- OfPieChart
- Represents an Excel Pie-of-Pie or Bar-of-Pie Chart.
- OfPieChartBuilder
- Builder for OfPie (Pie-of-Pie and Bar-of-Pie) chart styles.
- OtherColors
- Parser
-
Orchestrates the full parsing of an
.xlsxarchive. - PieChart
- Represents an Excel Pie Chart.
- PieChartBuilder
- Builder for Pie and Doughnut chart styles.
- PivotTable
- Represents a Pivot Table configuration to be generated programmatically.
- PivotTableValue
- Represents a single value/data field in a Pivot Table.
- RadarChart
- Represents an Excel Radar Chart.
- RadarChartBuilder
- Builder for Radar chart styles with optional fill.
- RedColors
- Save
- ScatterChart
- Represents an Excel Scatter (XY) Chart.
- ScatterChartBuilder
- Builder for Scatter (XY) chart styles.
- Sheet
- SheetProtection
- StandardDateTimeNumFormat
- StandardFormats
- Helper to keep NumFormat clean. Format codes follow ECMA-376 18.8.30 and Microsoft's built-in format table.
- StandardNumericNumFormat
- StandardNumFormat
- StandardTimeNumFormat
- StockChart
- Represents an Excel Stock Chart (High-Low-Close, Open-High-Low-Close, etc.).
- StockChartBuilder
- Builder for Stock chart styles (HLC, OHLC, etc.).
- TextCellValue
- Represents a text value in a cell, supporting rich text through spans.
- TextSpan
- TimeCellValue
- TimeNumFormat
- YellowOrangeColors
Enums
- BorderStyle
- ChartFillType
- Fill style for a chart series.
- ChartGrouping
- Grouping mode for Column, Bar, Area, and Line charts.
- ColorType
- ConditionalFormattingOperator
- Enum representing comparison operators for ConditionalFormattingType.cellIs rules.
- ConditionalFormattingType
- Enum representing standard OpenXML conditional formatting rule types.
- ExcelImageType
- Supported image formats for embedding in Excel worksheets.
- FontFamily
- FontScheme
-
enum for setting
font scheme - HorizontalAlign
-
enum for setting
horizontal alignment - OfPieSplitType
- Method used to split data slices into the secondary pie/bar chart.
- OfPieType
- Subtype for OfPieChart (Pie-of-Pie or Bar-of-Pie).
- PivotValueFunction
- Supported aggregation functions for Pivot Table values.
- TextWrapping
-
enum for
wrappingup the text - Underline
-
Underline - VerticalAlign
-
enum for setting
vertical alignment
Extensions
- BoolParsing on String
- SheetCharts on Sheet
- SheetDataExt on Sheet
- SheetDimensions on Sheet
- SheetImages on Sheet
- SheetSpans on Sheet
- StringExt on String
Functions
-
getBorderStyleByName(
String name) → BorderStyle? -
getCellId(
int columnIndex, int rowIndex) → String -
getColumnAlphabet(
int columnIndex) → String - Returns Column based String alphabet when column index is passed
-
getColumnIndex(
String columnAlphabet) → int - Returns Column based int index when column alphabet is passed
-
getFontFamily(
FontFamily fontFamily) → String -
returns the
Font Family Name -
getSpanCellId(
int startColumn, int startRow, int endColumn, int endRow) → String -
return A2:B2 for spanning storage in unmerge list when
[0,2][2,2]is passed -
lettersToNumeric(
String letters) → int - Convert a character based column