PieChart class
Represents an Excel Pie Chart.
Constructors
-
PieChart({required String title, required List<
ChartSeries> series, required ChartAnchor anchor, bool showLegend = true, ChartDataLabels? dataLabels}) - Creates a new PieChart.
Properties
- anchor → ChartAnchor
-
finalinherited
- chartTagName → String
-
The XML element name for this chart type in ChartML (e.g., 'barChart', 'lineChart').
no setteroverride
- dataLabels → ChartDataLabels?
-
Optional data labels shown on every data point.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
ChartSeries> -
finalinherited
- showLegend → bool
-
finalinherited
- title → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited